# folium-glify-layer

A plugin for [Folium](https://github.com/python-visualization/folium) to provide fast webgl rendering for large GeoJSON FeatureCollections (currently limited to polygons, lines and points).

For docs and examples see src, example.py, or GlifyLayer notebook.

## install
```
pip install folium-glify-layer
```


## jupyter demo
```
conda env create -f environment.yml
conda activate folium-glify-example
jupyter lab
```